pilot.filemanagement.ssh_adaptor

Package pilot :: Package filemanagement :: Module ssh_adaptor |

# Module ssh_adaptor

source code

SSH-based coordination scheme between manager and agent

Classes
| SSHFileAdaptor BigData Coordination File Management for Pilot Store

Variables
| SSH_OPTS = ``'``-o UserKnownHostsFile=/dev/null -o StrictHostKeyCh``...``
| __package__ = ``'``pilot.filemanagement``'``

Variables Details

  ### SSH_OPTS Value:
      '-o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no -o Number
      OfPasswordPrompts=0'